@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from enum import Enum
 
 from .code_mappings import RoborockDockDustCollectionType, RoborockDockWashingModeType
@@ -84,7 +86,17 @@ class RoborockCommand(str, Enum):
     SET_SERVER_TIMER = "set_server_timer"
     APP_GET_INIT_STATUS = "get_init_status"
     SET_APP_TIMEZONE = "set_app_timezone"
+    GET_NETWORK_INFO = "get_network_info"
 
+class RoborockDeviceInfo:
+    def __init__(self, local_key: str, model: str):
+        self.local_key = local_key
+        self.model = model
+
+class RoborockLocalDeviceInfo(RoborockDeviceInfo):
+    def __init__(self, local_key: str, model: str, ip: str):
+        super().__init__(local_key, model)
+        self.ip = ip
 
 class RoborockDockSummary:
     def __init__(self, dust_collection_mode: RoborockDockDustCollectionType,
